@@ -7,7 +7,8 @@ from fastapi.openapi.utils import get_openapi
 
 from therapy import __version__
 from therapy.query import QueryHandler, InvalidParameterException
-from therapy.schemas import SearchService, NormalizationService
+from therapy.schemas import SearchService, NormalizationService, \
+    UnmergedNormalizationService
 
 
 query_handler = QueryHandler()
@@ -62,6 +63,17 @@ search_description = ("For each source, return strongest-match concepts for quer
                       "string provided by user")
 normalize_description = ("Return merged strongest-match concept for query string "
                          "provided by user.")
+merged_matches_summary = ("Given query, provide merged normalized record as a "
+                          "TherapyDescriptor.")
+merged_response_descr = "A response to a validly-formed query."
+normalize_q_descr = "Therapy to normalize."
+unmerged_matches_summary = ("Given query, provide source records corresponding to "
+                            "normalized concept.")
+unmerged_response_descr = ("Response containing source records contained within "
+                           "normalized concept.")
+unmerged_normalize_description = ("Return unmerged records associated with the "
+                                  "normalized result of the user-provided query "
+                                  "string.")
 
 
 @app.get("/therapy/search",
@@ -99,18 +111,13 @@ def search(q: str = Query(..., description=q_descr),
     return response
 
 
-merged_matches_summary = "Given query, provide merged normalized record."
-merged_response_descr = "A response to a validly-formed query."
-merged_q_descr = "Therapy to normalize."
-
-
 @app.get("/therapy/normalize",
          summary=merged_matches_summary,
-         operation_id="getQuerymergedResponse",
+         operation_id="getMergedRecord",
          response_description=merged_response_descr,
          response_model=NormalizationService,
          description=normalize_description)
-def normalize(q: str = Query(..., description=merged_q_descr),
+def normalize(q: str = Query(..., description=normalize_q_descr),
               infer_namespace: bool = Query(True, description=infer_descr)
               ) -> NormalizationService:
     """Return merged strongest-match concept for query string provided by
@@ -118,7 +125,8 @@ def normalize(q: str = Query(..., description=merged_q_descr),
 
     :param q: therapy search term
     :param bool infer_namespace: if True, try to infer namespace from query term.
-    :returns: JSON response with matching normalized record and source metadata
+    :returns: JSON response with matching normalized record provided as a
+    TherapyDescriptor, and source metadata
     """
     try:
         response = query_handler.normalize(html.unescape(q),
@@ -126,3 +134,25 @@ def normalize(q: str = Query(..., description=merged_q_descr),
     except InvalidParameterException as e:
         raise HTTPException(status_code=422, detail=str(e))
     return response
+
+
+@app.get("/therapy/normalize_unmerged",
+         summary=unmerged_matches_summary,
+         operation_id="getUnmergedRecords",
+         response_description=unmerged_response_descr,
+         response_model=UnmergedNormalizationService,
+         description=unmerged_normalize_description)
+def normalize_unmerged(q: str = Query(..., description=normalize_q_descr),
+                       infer_namespace: bool = Query(True, description=infer_descr),
+                       ) -> UnmergedNormalizationService:
+    """Return all individual records associated with a normalized concept.
+
+    :param q: therapy search term
+    :param bool infer_namespace: if True, try to infer namespace from query term.
+    :returns: JSON response with matching normalized record and source metadata
+    """
+    try:
+        response = query_handler.normalize_unmerged(html.unescape(q), infer_namespace)
+    except InvalidParameterException as e:
+        raise HTTPException(status_code=422, detail=str(e))
+    return response
